==> com.liferay.document.library.web-5.0.53-sources.jar: com/liferay/document/library/web/internal/portlet/action/DeleteDDMStructureMVCActionCommand.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.document.library.web.internal.portlet.action;

import com.liferay.document.library.constants.DLPortletKeys;
import com.liferay.dynamic.data.mapping.service.DDMStructureService;
import com.liferay.portal.kernel.portlet.bridges.mvc.BaseMVCActionCommand;
import com.liferay.portal.kernel.portlet.bridges.mvc.MVCActionCommand;
import com.liferay.portal.kernel.util.ParamUtil;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Eudaldo Alonso
 */
@Component(
	immediate = true,
	property = {
		"javax.portlet.name=" + DLPortletKeys.DOCUMENT_LIBRARY,
		"javax.portlet.name=" + DLPortletKeys.DOCUMENT_LIBRARY_ADMIN,
		"javax.portlet.name=" + DLPortletKeys.MEDIA_GALLERY_DISPLAY,
		"mvc.command.name=/document_library/ddm/delete_ddm_structure"
	},
	service = MVCActionCommand.class
)
public class DeleteDDMStructureMVCActionCommand extends BaseMVCActionCommand {

	@Override
	protected void doProcessAction(
			ActionRequest actionRequest, ActionResponse actionResponse)
		throws Exception {

		long[] deleteDDMStructureIds = null;

		long ddmStructureId = ParamUtil.getLong(
			actionRequest, "ddmStructureId");

		if (ddmStructureId > 0) {
			deleteDDMStructureIds = new long[] {ddmStructureId};
		}
		else {
			deleteDDMStructureIds = ParamUtil.getLongValues(
				actionRequest, "rowIds");
		}

		for (long deleteDDMStructureId : deleteDDMStructureIds) {
			_ddmStructureService.deleteStructure(deleteDDMStructureId);
		}
	}

	@Reference
	private DDMStructureService _ddmStructureService;

}

==> com.liferay.document.library.web-5.0.108-sources.jar: com/liferay/document/library/web/internal/portlet/action/DeleteDDMStructureMVCActionCommand.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.document.library.web.internal.portlet.action;

import com.liferay.document.library.constants.DLPortletKeys;
import com.liferay.dynamic.data.mapping.service.DDMStructureService;
import com.liferay.portal.kernel.portlet.bridges.mvc.BaseMVCActionCommand;
import com.liferay.portal.kernel.portlet.bridges.mvc.MVCActionCommand;
import com.liferay.portal.kernel.util.ParamUtil;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Eudaldo Alonso
 */
@Component(
	immediate = true,
	property = {
		"javax.portlet.name=" + DLPortletKeys.DOCUMENT_LIBRARY,
		"javax.portlet.name=" + DLPortletKeys.DOCUMENT_LIBRARY_ADMIN,
		"javax.portlet.name=" + DLPortletKeys.MEDIA_GALLERY_DISPLAY,
		"mvc.command.name=/document_library/delete_ddm_structure"
	},
	service = MVCActionCommand.class
)
public class DeleteDDMStructureMVCActionCommand extends BaseMVCActionCommand {

	@Override
	protected void doProcessAction(
			ActionRequest actionRequest, ActionResponse actionResponse)
		throws Exception {

		long[] deleteDDMStructureIds = null;

		long ddmStructureId = ParamUtil.getLong(
			actionRequest, "ddmStructureId");

		if (ddmStructureId > 0) {
			deleteDDMStructureIds = new long[] {ddmStructureId};
		}
		else {
			deleteDDMStructureIds = ParamUtil.getLongValues(
				actionRequest, "rowIds");
		}

		for (long deleteDDMStructureId : deleteDDMStructureIds) {
			_ddmStructureService.deleteStructure(deleteDDMStructureId);
		}
	}

	@Reference
	private DDMStructureService _ddmStructureService;

}
